@@ -7,7 +7,7 @@ import time
 from types import ModuleType
 from typing import Any, cast, Dict, List, Optional
 
-from openapi_client.rest import ApiException  # type: ignore
+from openapi_client.rest import ApiException
 from ray.autoscaler._private.aws.node_provider import to_aws_format
 from ray.autoscaler._private.command_runner import DockerCommandRunner, SSHCommandRunner
 from ray.autoscaler._private.util import hash_launch_conf
@@ -16,15 +16,13 @@ from ray.autoscaler.tags import TAG_RAY_CLUSTER_NAME
 from urllib3.exceptions import HTTPError  # type: ignore
 import wrapt
 
+
 # This try block exists because
 # 1. This module is passed to the autoscaler on the head node as an external node provider
 # 2. Import paths are different for different versions of ray
 try:
+    from ray.autoscaler._private.providers import _get_node_provider, _NODE_PROVIDERS
     from ray.autoscaler.node_provider import NodeProvider
-    from ray.autoscaler._private.providers import (
-        _get_node_provider,
-        _NODE_PROVIDERS,
-    )
 except ModuleNotFoundError:
     from ray.autoscaler.aws.node_provider import NodeProvider
     from ray.autoscaler.node_provider import (
@@ -33,25 +31,30 @@ except ModuleNotFoundError:
     )
 
 from anyscale.api import instantiate_api_client
-from anyscale.client.openapi_client.api.default_api import DefaultApi  # type: ignore
-from anyscale.client.openapi_client.models.add_instance_pool_member import AddInstancePoolMember  # type: ignore
-from anyscale.client.openapi_client.models.create_nodes_options import (  # type: ignore
+from anyscale.client.openapi_client.api.default_api import DefaultApi
+from anyscale.client.openapi_client.models.add_instance_pool_member import (
+    AddInstancePoolMember,
+)
+from anyscale.client.openapi_client.models.create_nodes_options import (
     CreateNodesOptions,
 )
-from anyscale.client.openapi_client.models.nodes_options import NodesOptions  # type: ignore
-from anyscale.client.openapi_client.models.non_terminated_nodes_options import (  # type: ignore
+from anyscale.client.openapi_client.models.nodes_options import NodesOptions
+from anyscale.client.openapi_client.models.non_terminated_nodes_options import (
     NonTerminatedNodesOptions,
 )
-from anyscale.client.openapi_client.models.query_pool_size import QueryPoolSize  # type: ignore
-from anyscale.client.openapi_client.models.request_instance_pool_member import RequestInstancePoolMember  # type: ignore
-from anyscale.client.openapi_client.models.set_node_tags_options import (  # type: ignore
+from anyscale.client.openapi_client.models.query_pool_size import QueryPoolSize
+from anyscale.client.openapi_client.models.request_instance_pool_member import (
+    RequestInstancePoolMember,
+)
+from anyscale.client.openapi_client.models.set_node_tags_options import (
     SetNodeTagsOptions,
 )
-from anyscale.client.openapi_client.models.wait_until_stopped_options import (  # type: ignore
+from anyscale.client.openapi_client.models.wait_until_stopped_options import (
     WaitUntilStoppedOptions,
 )
 from anyscale.util import format_api_exception, get_autoscaler_container_path
 
+
 logger = logging.getLogger(__name__)
 RETRY_COUNT = 5
 
