@@ -9,12 +9,13 @@ import time
 from typing import cast, Dict, Iterator, List, Optional
 
 import click
-from openapi_client.rest import ApiException  # type: ignore
+from openapi_client.rest import ApiException
 
 import anyscale
-from anyscale.client.openapi_client.api.default_api import DefaultApi  # type: ignore
+from anyscale.client.openapi_client.api.default_api import DefaultApi
 from anyscale.util import format_api_exception, get_rsync_command, send_json_request
 
+
 logger = logging.getLogger(__file__)
 logging.getLogger("botocore").setLevel(logging.CRITICAL)
 
@@ -26,9 +27,7 @@ TIME_BETWEEN_HEARTBEATS = 30  # seconds
 
 
 @contextmanager
-def managed_autosync_session(
-    session_id: str, api_client: DefaultApi = None
-) -> Iterator[str]:
+def managed_autosync_session(session_id: str, api_client: DefaultApi) -> Iterator[str]:
     # Register to the API that we enabled autosync
     with format_api_exception(ApiException):
         resp = api_client.register_autosync_session_api_v2_autosync_sessions_post(
