@@ -1,9 +1,9 @@
 from typing import Any, Dict, Optional, Tuple
 
 from click import ClickException
-from openapi_client.rest import ApiException  # type: ignore
+from openapi_client.rest import ApiException
 
-from anyscale.client.openapi_client.api.default_api import DefaultApi  # type: ignore
+from anyscale.client.openapi_client.api.default_api import DefaultApi
 from anyscale.util import format_api_exception
 
 
