@@ -7,7 +7,7 @@ from typing import Any, Callable, Dict, MutableMapping, Optional
 import click
 import wrapt
 
-from anyscale.client.openapi_client.api.default_api import DefaultApi  # type: ignore
+from anyscale.client.openapi_client.api.default_api import DefaultApi
 from anyscale.conf import ANYSCALE_AWS_SECURITY_GROUP_NAME
 from anyscale.project import get_project_id, get_project_session, load_project_or_throw
 from anyscale.util import get_working_dir, send_json_request
