@@ -8,7 +8,13 @@ import click
 
 from anyscale.api import get_anyscale_api_client
 from anyscale.formatters import common_formatter
-from anyscale.sdk.anyscale_client import CreateSession, StartSessionOptions, StopSessionOptions, TerminateSessionOptions, UpdateSession  # type: ignore
+from anyscale.sdk.anyscale_client import (
+    CreateSession,
+    StartSessionOptions,
+    StopSessionOptions,
+    TerminateSessionOptions,
+    UpdateSession,
+)
 
 
 @click.group(
