@@ -27,6 +27,24 @@ def cloud_delete(cloud_name: str, cloud_id: str, yes: bool) -> None:
     )
 
 
+@cloud_cli.command(
+    name="set-default",
+    help=(
+        "Sets default cloud for your organization. This operation can only be performed "
+        "by organization admins, and the default cloud must have organization level "
+        "permissions."
+    ),
+)
+@click.argument("cloud-name", required=False)
+@click.option(
+    "--cloud-id",
+    help="Cloud id to set as default. Alternative to cloud name.",
+    required=False,
+)
+def cloud_set_default(cloud_name: str, cloud_id: str) -> None:
+    CloudController().set_default_cloud(cloud_name=cloud_name, cloud_id=cloud_id)
+
+
 @cloud_cli.command(name="setup", help="Set up a cloud provider.")
 @click.option(
     "--provider",
