@@ -6,14 +6,13 @@ import json
 import time
 from typing import Any, Dict, List, Optional, Tuple
 
-from openapi_client.rest import ApiException  # type: ignore
+from openapi_client.rest import ApiException
 import tabulate
 
 from anyscale.api import get_api_client
-from anyscale.client.openapi_client.api.default_api import DefaultApi  # type: ignore
+from anyscale.client.openapi_client.api.default_api import DefaultApi
 from anyscale.cloud import get_cloud_json_from_id
 from anyscale.cluster_config import get_cluster_config
-import anyscale.conf
 from anyscale.formatters import clouds_formatter
 from anyscale.project import (
     get_proj_name_from_id,
@@ -22,7 +21,7 @@ from anyscale.project import (
     get_project_sessions,
     load_project_or_throw,
 )
-from anyscale.util import format_api_exception, humanize_timestamp
+from anyscale.util import format_api_exception, get_endpoint, humanize_timestamp
 
 
 class ListController(object):
@@ -62,18 +61,14 @@ class ListController(object):
                     {
                         "name": project.name,
                         "sessions": session_record,
-                        "url": "{}/projects/{}".format(
-                            anyscale.conf.ANYSCALE_HOST, project.id
-                        ),
+                        "url": "{}".format(get_endpoint(f"/projects/{project.id}")),
                     }
                 )
             else:
                 project_table.append(
                     [
                         project.name,
-                        "{}/projects/{}".format(
-                            anyscale.conf.ANYSCALE_HOST, project.id
-                        ),
+                        get_endpoint(f"/projects/{project.id}"),
                         project.description,
                     ]
                 )
@@ -288,10 +283,7 @@ class ListController(object):
 
     # TODO (jbai): Reorganize to other files
     def _get_head_and_worker_ips(self, session_name: str) -> Tuple[str, List[str]]:
-        from ray.autoscaler.sdk import (
-            get_head_node_ip,
-            get_worker_node_ips,
-        )
+        from ray.autoscaler.sdk import get_head_node_ip, get_worker_node_ips
 
         cluster_config = get_cluster_config(session_name, self.api_client)
         head_ip = get_head_node_ip(cluster_config)
@@ -314,6 +306,7 @@ class ListController(object):
             )
 
             record["created_at"] = time.mktime(session.created_at.timetuple())
+            record["connect_url"] = session.connect_url
             record["jupyter_notebook_url"] = session.jupyter_notebook_url
             record["ray_dashboard_url"] = session.ray_dashboard_url
             record["grafana_url"] = session.metrics_dashboard_url
