@@ -2,20 +2,23 @@ from datetime import datetime
 import json
 import os
 import subprocess
-from typing import Any, Dict, Optional, Tuple, Union
+import sys
+from typing import Any, Dict, List, Optional, Tuple, Union
 
 import click
-from openapi_client.rest import ApiException  # type: ignore
+from openapi_client.rest import ApiException
 import yaml
 
-from anyscale.api import get_api_client
+from anyscale.api import get_anyscale_api_client, get_api_client
 from anyscale.autosync_heartbeat import (
     get_working_dir_host_mount_location,
     managed_autosync_session,
     perform_autopush_synchronization,
     perform_sync,
 )
-from anyscale.client.openapi_client import (  # type: ignore
+from anyscale.client.openapi_client import (
+    AppConfig,
+    Build,
     ComputeTemplateConfig,
     CreateComputeTemplate,
     CreateSessionFromSnapshotOptions,
@@ -25,7 +28,7 @@ from anyscale.client.openapi_client import (  # type: ignore
     SetupInitializeSessionOptions,
     StopSessionOptions,
 )
-from anyscale.client.openapi_client.api.default_api import DefaultApi  # type: ignore
+from anyscale.client.openapi_client.api.default_api import DefaultApi
 from anyscale.cloud import get_cloud_id_and_name
 from anyscale.cluster_config import (
     _configure_min_max_workers,
@@ -38,6 +41,11 @@ from anyscale.project import (
     get_project_sessions,
     load_project_or_throw,
 )
+from anyscale.sdk.anyscale_client import (
+    CreateSession,
+    StartSessionOptions,
+    UpdateSession,
+)
 from anyscale.util import (
     canonicalize_remote_location,
     format_api_exception,
@@ -69,10 +77,17 @@ def rsync(*args: Any, **kwargs: Any) -> None:
 
 
 class SessionController:
-    def __init__(self, api_client: Optional[DefaultApi] = None):
+    def __init__(
+        self,
+        api_client: Optional[DefaultApi] = None,
+        anyscale_api_client: Optional[DefaultApi] = None,
+    ):
         if api_client is None:
             api_client = get_api_client()
+        if anyscale_api_client is None:
+            anyscale_api_client = get_anyscale_api_client()
         self.api_client = api_client
+        self.anyscale_api_client = anyscale_api_client
 
     def stop(
         self,
@@ -84,13 +99,15 @@ class SessionController:
     ) -> None:
         project_definition = load_project_or_throw()
         project_id = get_project_id(project_definition.root)
-        sessions = get_project_sessions(project_id, session_name, self.api_client)
+        sessions = get_project_sessions(
+            project_id, session_name, self.api_client, all_active_states=True
+        )
 
         if not session_name and len(sessions) > 1:
             raise click.ClickException(
                 "Multiple active sessions: {}\n"
                 "Please specify the one you want to stop with --session-name.".format(
-                    [session["name"] for session in sessions]
+                    [session.name for session in sessions]
                 )
             )
 
@@ -112,37 +129,55 @@ class SessionController:
         url = get_endpoint(f"/projects/{project_id}")
         print(f"Session {session_names_str} shutting down. View progress at {url}")
 
-    def _load_cluster_config(
-        self, config: Optional[str], session_exists: bool, project_definition: Any
-    ) -> Optional[Dict[str, Any]]:
-        """config option to cluster config.
+    def start(
+        self,
+        session_name: Optional[str],
+        build_id: Optional[str],
+        build_identifier: Optional[str],
+        compute_config: str,
+        idle_timeout: Optional[int],
+        sync_files: bool,
+    ) -> None:
+        if sync_files:
+            raise click.ClickException(
+                "--sync-files has been deprecated and `anyscale start` will no longer ensure files "
+                "synced to the working directory of the head node will also be synced on the workers."
+            )
+        message = (
+            "Warning: `anyscale start` has been deprecated. Please try "
+            "using `anyscale.connect()` for your use case and let the Anyscale team "
+            "know if you are having any issues."
+        )
+        print("\033[91m{}\033[00m".format(message), file=sys.stderr)
 
-        Excision of existing logic for C901.
-        """
-        cluster_config = None
-        if not session_exists:
-            config_attribute_provided = True
-            if not config:
-                config_attribute_provided = False
-                config = project_definition.cluster_yaml()
+        project_definition = load_project_or_throw()
+        project_id = get_project_id(project_definition.root)
+        session_name = self._get_or_generate_session_name(session_name, project_id)
 
-            config = str(config)  # for typing.
-            if not os.path.exists(config):
-                if config_attribute_provided:
-                    raise ValueError("Config file {} not found".format(config))
-                else:
-                    raise ValueError(
-                        "No config param provided and default config file session-default.yaml not found. Please provide a config file using the --config attribute."
-                    )
+        assert (
+            build_id or build_identifier
+        ), "--build-id or --build-identifier must be specified."
+        if not build_id and build_identifier:
+            build_id = self._get_build_id_from_build_identifier(
+                build_identifier, project_id
+            )
+        assert build_id  # for mypy
 
-        if config:
-            with open(config) as f:
-                cluster_config_filled = populate_session_args(f.read(), config)
-                cluster_config = yaml.safe_load(cluster_config_filled)
+        compute_template_id = self._register_compute_config(compute_config, project_id)
 
-            validate_cluster_configuration(config, cluster_config, self.api_client)
+        session = self._create_or_update_session_data(
+            session_name, project_id, build_id, compute_template_id, idle_timeout
+        )
+        self.anyscale_api_client.start_session(
+            session.id,
+            StartSessionOptions(
+                build_id=build_id, compute_template_id=compute_template_id
+            ),
+        )
 
-        return cluster_config
+        wait_for_session_start(project_id, session_name, self.api_client)
+        url = get_endpoint(f"/projects/{project_id}/sessions/{session.id}")
+        print(f"Session {session_name} finished starting. View at {url}")
 
     def up(
         self,
@@ -550,7 +585,25 @@ class SessionController:
         target: Optional[str],
         config: Optional[str],
         all_nodes: bool,
+        no_warning: bool = False,
     ) -> None:
+        if all_nodes:
+            raise click.ClickException(
+                "The `all_nodes` option is deprecated and will be removed in the future. "
+                "Pushing to worker nodes is not reliable since workers may be "
+                "added during autoscaling. Going forward, Anyscale will only support syncing "
+                "working directory files to the head and workers."
+            )
+        if (source or target) and not no_warning:
+            message = (
+                "Warning: The --source and --target options will soon be deprecated "
+                "for `anyscale push`. Going forward, Anyscale will only support syncing "
+                "the project directory files (which can be done without passing any "
+                "--source any --target arguments). Please let the Anyscale team know if "
+                "this will block your use case."
+            )
+            print("\033[91m{}\033[00m".format(message), file=sys.stderr)
+
         project_definition = load_project_or_throw()
         project_id = get_project_id(project_definition.root)
         session = get_project_session(project_id, session_name, self.api_client)
@@ -599,6 +652,170 @@ class SessionController:
 
     # Helpers
 
+    def _get_or_generate_session_name(
+        self, session_name: Optional[str], project_id: Optional[str]
+    ) -> str:
+        """
+        Return slugified session name if provided, else generate default session name from project id
+        """
+        assert (
+            session_name or project_id
+        ), "Either the session_name or project_id must be provided"
+
+        if not session_name:
+            session_name = str(
+                self.api_client.get_project_default_session_name_api_v2_projects_project_id_default_session_name_get(
+                    project_id=project_id,
+                ).result.name
+            )
+        else:
+            session_name = slugify(session_name)
+        return session_name
+
+    def _register_compute_config(
+        self, compute_config_file: str, project_id: str
+    ) -> str:
+        """
+        Register the compute config with Anyscale and get its ID.
+        """
+        with open(compute_config_file, "r") as f:
+            config_dict = json.load(f)
+        config_object = ComputeTemplateConfig(**config_dict)
+        created_template = self.api_client.create_compute_template_api_v2_compute_templates_post(
+            create_compute_template=CreateComputeTemplate(
+                name="autogenerated-config-{}".format(datetime.now().isoformat()),
+                project_id=project_id,
+                config=config_object,
+            )
+        ).result
+        compute_template_id = str(created_template.id)
+        return compute_template_id
+
+    def _create_or_update_session_data(
+        self,
+        session_name: str,
+        project_id: str,
+        build_id: str,
+        compute_template_id: str,
+        idle_timeout: Optional[int],
+    ) -> Session:
+        """
+        Creates new session with app configs if session with `session_name` doesn't
+        already exist. Otherwise, update the `idle_timeout` of the existing
+        session if provided.
+        """
+        session_list = self.api_client.list_sessions_api_v2_sessions_get(
+            project_id=project_id, active_only=False, name=session_name
+        ).results
+
+        session_exists = len(session_list) > 0
+        if not session_exists:
+            # Create a new session if there is no existing session with the givens session_name
+            create_session_data = CreateSession(
+                name=session_name,
+                project_id=project_id,
+                cloud_id=None,
+                cluster_config=None,
+                build_id=build_id,
+                compute_template_id=compute_template_id,
+                idle_timeout=idle_timeout,
+                uses_app_config=True,
+            )
+            session = self.anyscale_api_client.create_session(
+                create_session_data
+            ).result
+        else:
+            # Get the existing session and update the idle_timeout if required
+            session = session_list[0]
+            if idle_timeout:
+                self.anyscale_api_client.update_session(
+                    session.id, UpdateSession(idle_timeout=idle_timeout)
+                )
+
+        return session
+
+    def _get_build_id_from_build_identifier(
+        self, build_identifier: str, project_id: str
+    ) -> str:
+        # TODO(nikita): App config API should support getting a build ID from the build identifier.
+        components = build_identifier.rsplit(":", 1)
+        app_config_name = components[0]
+        # try catch this
+        try:
+            app_config_revision = int(components[1]) if len(components) > 1 else None
+        except ValueError:
+            raise click.ClickException(
+                "Invalid build-identifier provided. Please make sure the build identifier is of "
+                "the form <app-config-name>:<build-revision>."
+            )
+
+        app_config_id = self._get_app_config_id_from_name(app_config_name, project_id)
+
+        builds = self._list_builds(app_config_id)
+        if app_config_revision:
+            for build in builds:
+                if build.revision == app_config_revision:
+                    return str(build.id)
+
+            raise click.ClickException(
+                "Revision {} of app config '{}' not found.".format(
+                    app_config_revision, app_config_name
+                )
+            )
+        else:
+            latest_build_revision = -1
+            build_to_use = None
+            for build in builds:
+                if build.revision > latest_build_revision:
+                    latest_build_revision = build.revision
+                    build_to_use = build
+
+            if not build_to_use:
+                raise click.ClickException(
+                    "Error finding latest build of app config {}. Please manually "
+                    "specify the build version in the build identifier.".format(
+                        app_config_name
+                    )
+                )
+            return str(build_to_use.id)
+
+    def _get_app_config_id_from_name(
+        self, app_config_name: str, project_id: str
+    ) -> str:
+        app_configs = self._list_app_configs(project_id)
+        for app_config in app_configs:
+            if app_config.name == app_config_name:
+                return str(app_config.id)
+
+        raise click.ClickException(
+            "Application config '{}' not found. ".format(app_config_name)
+            + "Available app configs: {}".format(", ".join(a.name for a in app_configs))
+        )
+
+    def _list_app_configs(self, project_id: str) -> List[AppConfig]:
+        entities = []
+        has_more = True
+        while has_more:
+            resp = self.anyscale_api_client.list_app_configs(
+                project_id, count=50, paging_token=None
+            )
+            entities.extend(resp.results)
+            paging_token = resp.metadata.next_paging_token
+            has_more = paging_token is not None
+        return entities
+
+    def _list_builds(self, app_config_id: str) -> List[Build]:
+        entities = []
+        has_more = True
+        while has_more:
+            resp = self.anyscale_api_client.list_builds(
+                app_config_id, count=50, paging_token=None
+            )
+            entities.extend(resp.results)
+            paging_token = resp.metadata.next_paging_token
+            has_more = paging_token is not None
+        return entities
+
     def _resolve_session(
         self, session_name: str, project_name: Optional[str] = None
     ) -> Session:
