@@ -2,17 +2,16 @@ import json
 import os
 import shutil
 import sys
-from typing import Any, Dict, Optional, Tuple
+from typing import Any, Optional, Tuple
 
 import click
 from click import ClickException
-import jsonschema
-from openapi_client.rest import ApiException  # type: ignore
+from openapi_client.rest import ApiException
 import yaml
 
 import anyscale
 from anyscale.api import get_api_client
-from anyscale.client.openapi_client.api.default_api import DefaultApi  # type: ignore
+from anyscale.client.openapi_client.api.default_api import DefaultApi
 from anyscale.util import (
     format_api_exception,
     get_endpoint,
@@ -21,6 +20,7 @@ from anyscale.util import (
     validate_cluster_configuration,
 )
 
+
 ANYSCALE_PROJECT_FILE = ".anyscale.yaml"
 ANYSCALE_AUTOSCALER_FILE = "session-default.yaml"
 
@@ -34,21 +34,6 @@ CLUSTER_CONFIG_TEMPLATE_STR = json.dumps(
 )
 
 
-def validate_project_schema(project_config: Dict[str, str]) -> Any:
-    """Validate a project config against the project schema.
-    Args:
-        project_config (dict): Parsed project yaml.
-    Raises:
-        jsonschema.exceptions.ValidationError: This exception is raised
-            if the project file is not valid.
-    """
-    dir = os.path.dirname(os.path.abspath(__file__))
-    with open(os.path.join(dir, "ProjectConfig.json")) as f:
-        schema = json.load(f)
-
-    jsonschema.validate(instance=project_config, schema=schema)
-
-
 def find_project_root(directory: str) -> Optional[str]:
     """Find root directory of the project.
 
@@ -135,18 +120,35 @@ def validate_project_name(project_name: str) -> bool:
 
 
 def get_project_sessions(
-    project_id: str, session_name: Optional[str], api_client: DefaultApi = None
+    project_id: str,
+    session_name: Optional[str],
+    api_client: DefaultApi = None,
+    all_active_states: bool = False,
 ) -> Any:
+    """
+    Returns active project sessions. If `all_active_states` is set, returns sessions with
+        the following states: StartingUp, _StartingUp, StartupErrored, Running, Updating,
+        UpdatingErrored, AwaitingFileMounts. Otherwise, only return sessions in the
+        Running and AwaitingFileMounts state.
+    """
     if api_client is None:
         return _get_project_sessions(project_id, session_name)
 
     with format_api_exception(ApiException):
-        response = api_client.list_sessions_api_v2_sessions_get(
-            project_id=project_id,
-            name_match=session_name,
-            active_only=True,
-            _request_timeout=30,
-        )
+        if all_active_states:
+            response = api_client.list_sessions_api_v2_sessions_get(
+                project_id=project_id,
+                name_match=session_name,
+                active_only=True,
+                _request_timeout=30,
+            )
+        else:
+            response = api_client.list_sessions_api_v2_sessions_get(
+                project_id=project_id,
+                name_match=session_name,
+                state_filter=["AwaitingFileMounts", "Running"],
+                _request_timeout=30,
+            )
     sessions = response.results
     if len(sessions) == 0:
         raise ClickException(
