@@ -8,7 +8,7 @@ import click
 from packaging import version
 
 from anyscale.api import instantiate_api_client
-from anyscale.client.openapi_client.rest import ApiException  # type: ignore
+from anyscale.client.openapi_client.rest import ApiException
 from anyscale.commands.anyscale_api.api_commands import anyscale_api
 from anyscale.commands.cloud_commands import cloud_cli
 from anyscale.commands.exec_commands import anyscale_exec
@@ -21,15 +21,13 @@ from anyscale.commands.session_commands import (
     anyscale_pull,
     anyscale_push,
     anyscale_ssh,
+    anyscale_start,
     anyscale_stop,
     anyscale_up,
 )
-from anyscale.commands.session_commands_hidden import (
-    anyscale_start,
-    session_cli,
-)
-from anyscale.commands.snapshot_commands_hidden import snapshot_cli
+from anyscale.commands.session_commands_hidden import session_cli
 import anyscale.conf
+from anyscale.util import init_sentry
 
 
 logger = logging.getLogger(__file__)
@@ -73,6 +71,7 @@ class AliasedGroup(click.Group):
 )
 @click.pass_context
 def cli(ctx: Any, version_flag: bool, show_json: bool) -> None:
+    init_sentry(ctx)
 
     # Use anyscale vendored Ray for the CLI:
     sys.path.insert(0, anyscale.ANYSCALE_RAY_DIR)
@@ -131,13 +130,11 @@ def anyscale_help(ctx: Any) -> None:
 
 
 cli.add_command(session_cli)
-cli.add_command(snapshot_cli)
 cli.add_command(cloud_cli)
 cli.add_command(version_cli)
 cli.add_command(list_cli)
 
 cli.add_command(anyscale_init)
-cli.add_command(anyscale_start)
 cli.add_command(anyscale_up)
 cli.add_command(anyscale_stop)
 cli.add_command(anyscale_autosync)
@@ -145,6 +142,7 @@ cli.add_command(anyscale_autopush)
 cli.add_command(anyscale_fork)
 cli.add_command(anyscale_clone)
 cli.add_command(anyscale_ssh)
+cli.add_command(anyscale_start)
 cli.add_command(anyscale_exec)
 cli.add_command(anyscale_pull)
 cli.add_command(anyscale_push)
