@@ -1,9 +1,11 @@
+import base64
 from contextlib import contextmanager
 import datetime
 import json
 import logging
 import os
 import re
+import subprocess
 import sys
 import threading
 import time
@@ -18,11 +20,13 @@ from requests import Response
 import yaml
 
 from anyscale.api import get_api_client
-from anyscale.client.openapi_client.api.default_api import DefaultApi  # type: ignore
-from anyscale.client.openapi_client.rest import ApiException  # type: ignore
+from anyscale.client.openapi_client.api.default_api import DefaultApi
+from anyscale.client.openapi_client.models.user_info import UserInfo
+from anyscale.client.openapi_client.rest import ApiException
 import anyscale.conf
 from anyscale.credentials import load_credentials
 
+
 logger = logging.getLogger(__file__)
 
 BOTO_MAX_RETRIES = 5
@@ -100,17 +104,6 @@ def send_json_request(
     return json_resp
 
 
-# DEPRECATED
-def serialize_datetime(d: datetime.datetime) -> str:
-    # Make sure that overwriting the tzinfo in the line below is fine.
-    # Note that we have to properly convert the timezone if one is
-    # already specified. This can be done with the .astimezone method.
-    if d.tzinfo is None:
-        return d.replace(tzinfo=datetime.timezone.utc).isoformat()
-    else:
-        return d.astimezone(datetime.timezone.utc).isoformat()
-
-
 def deserialize_datetime(s: str) -> datetime.datetime:
     if sys.version_info < (3, 7) and ":" == s[-3:-2]:
         s = s[:-3] + s[-2:]
@@ -149,6 +142,18 @@ def startup_log_name(session_id: str) -> str:
     return "/tmp/session_startup_logs_{session_id}".format(session_id=session_id)
 
 
+def startup_log_name_v2(session_id: str, encoded: bool = False) -> str:
+    startup_log_name = "/var/log/anyscale/session_startup_logs_{session_id}".format(
+        session_id=session_id
+    )
+
+    if encoded:
+        # The encoding should be the same as `encodePathToFileName` in go/infra/anyscaled/internal/logcache/utils.go
+        return base64.standard_b64encode(f"{startup_log_name}.out".encode()).decode()
+    else:
+        return startup_log_name
+
+
 def slugify(value: str) -> str:
     """
     Code adopted from here https://github.com/django/django/blob/master/django/utils/text.py
@@ -318,6 +323,9 @@ def get_autoscaler_container_path(path: str) -> str:
 
 
 def get_project_directory_name(project_id: str, api_client: DefaultApi = None) -> str:
+    if api_client is None:
+        api_client = get_api_client()
+
     # TODO (yiran): return error early if project doesn't exist.
     with format_api_exception(ApiException):
         resp = api_client.get_project_api_v2_projects_project_id_get(project_id)
@@ -435,6 +443,7 @@ def wait_for_head_node_start(
                 retry_count >= 2
                 and session.state
                 and session.state in {"Terminated", "Stopped"}
+                and session.pending_state is None
             ):
                 # Session is created in Terminated state; Ignore the first few state checks.
                 raise click.ClickException(
@@ -623,3 +632,65 @@ def format_api_exception(exception_type: Type[Exception]) -> Iterator[None]:
         raise click.ClickException(
             "{0}: {1}".format(e.status, json.loads(e.body)["error"]["detail"])  # type: ignore
         )
+
+
+def init_sentry(ctx: click.core.Context) -> None:
+    # Only report production and staging errors
+    if anyscale.conf.ANYSCALE_ENV not in ["production", "staging"]:
+        return
+
+    import sentry_sdk
+
+    user_info = get_user_info()
+    if user_info:
+        if user_info.email in [
+            "test@anyscale.com",
+            "ci-staging@anyscale.com",
+            "ci-production@anyscale.com",
+        ]:
+            return
+        sentry_sdk.set_user(
+            {
+                "id": user_info.id,
+                "email": user_info.email,
+                "username": user_info.username,
+            }
+        )
+
+    sentry_sdk.set_tag("command", ctx.invoked_subcommand)
+    sentry_sdk.init(
+        "https://68d7689b55024e91bb31694539111baa@o565360.ingest.sentry.io/5706818",
+        release=get_anyscale_version(),
+        environment=anyscale.conf.ANYSCALE_ENV,
+    )
+
+
+def get_user_info() -> Optional[UserInfo]:
+    try:
+        api_client = get_api_client()
+    except click.exceptions.ClickException:
+        return None
+    return api_client.get_user_info_api_v2_userinfo_get().result
+
+
+def get_anyscale_version() -> str:
+    # Return git sha if anyscale pip package was built in development mode
+    from pip._internal.operations.freeze import FrozenRequirement
+    import pkg_resources
+
+    distributions = {v.key: v for v in pkg_resources.working_set}
+    distribution = distributions["anyscale"]
+    frozen_requirement = FrozenRequirement.from_dist(distribution)  # type: ignore
+    if frozen_requirement.editable:
+        try:
+            return (
+                subprocess.check_output(  # noqa: B1
+                    ["git", "describe", "--always"],
+                    cwd=os.path.dirname(os.path.realpath(__file__)),
+                )  # noqa: B1
+                .strip()
+                .decode("utf-8")
+            )
+        except subprocess.CalledProcessError:
+            print("Not a git repository, will use standard release versioning")
+    return anyscale.__version__
