@@ -2,8 +2,10 @@ import asyncio
 from typing import Dict, List
 
 from anyscale.api import instantiate_api_client
-from anyscale.client.openapi_client.api.default_api import DefaultApi  # type: ignore
-from anyscale.client.openapi_client.models.session_command_types import SessionCommandTypes  # type: ignore
+from anyscale.client.openapi_client.api.default_api import DefaultApi
+from anyscale.client.openapi_client.models.session_command_types import (
+    SessionCommandTypes,
+)
 from anyscale.commands.session_commands_hidden import session_upload_command_logs_impl
 from anyscale.webterminal.utils import Command
 
