@@ -22,16 +22,6 @@ def generate_session_command_id() -> str:
     return f"scd_{generate_id()}"
 
 
-def generate_() -> str:
-    """
-    generate_session_command_id is a mirror from
-    backend/server/utils/id_gen.py. Consult this
-    source of truth for changes
-    """
-    id_part = base62.encodebytes(secrets.token_bytes(16))
-    return f"scd_{id_part}"
-
-
 # *_DELIMITER are used within preexec / precmd zsh hooks to so that
 # we can parse out command information for logging commands, their outputs
 # and their statuses.
