@@ -62,6 +62,12 @@ class AnyscaleTermManager(NamedTermManager):  # type: ignore
         term.ptyproc.write(f"{EXEC_ZSH_CMD}\n")
         return name, term
 
+    def terminal_count(self, include_all: bool = False) -> int:
+        return sum(
+            self.is_exec_command[term_name] is None or include_all
+            for term_name in self.terminals.keys()
+        )
+
     def pty_read(self, fd: Any, events: Any = None) -> None:
         """
         Called by the event loop when there is pty data ready to read.
@@ -164,17 +170,29 @@ class TerminalListHandler(tornado.web.RequestHandler):
             self.get_query_argument("all_terms", default="false")
             or "false"  # this additional false is added bc mypy complains.
         )
-        data = {
-            "terminals": [
+        create_if_none = json.loads(
+            self.get_query_argument("create_if_none", default="false")
+            or "false"  # this additional false is added bc mypy complains.
+        )
+        terminals = [
+            {
+                "id": term_name,
+                "debugger": term_manager.is_debugger[term_name],
+                "exec_command": term_manager.is_exec_command[term_name] is not None,
+            }
+            for term_name in term_manager.terminals.keys()
+            if (term_manager.is_exec_command[term_name] is None or include_all)
+        ]
+        if term_manager.terminal_count() == 0 and create_if_none:
+            term_name, _ = term_manager.new_named_terminal()
+            terminals.append(
                 {
                     "id": term_name,
                     "debugger": term_manager.is_debugger[term_name],
                     "exec_command": term_manager.is_exec_command[term_name] is not None,
                 }
-                for term_name in term_manager.terminals.keys()
-                if (term_manager.is_exec_command[term_name] is None or include_all)
-            ]
-        }
+            )
+        data = {"terminals": terminals}
 
         self.write(data)
 
