@@ -52,3 +52,24 @@ def test_ensure_no_credentials_on_head_node_config(
 
     assert "aws_credentials" not in provider_config
     assert "aws_credentials" not in provider_config.get("inner_provider", {})
+
+
+def test_create_node_return() -> None:
+    mock_ec2_client = Mock()
+    mock_instance_id = "fake_instance_id"
+    mock_instance_ip = "fake_ip"
+    mock_ec2_instance = Mock()
+    mock_ec2_instance.id = mock_instance_id
+    mock_ec2_instance.public_ip_address = mock_instance_ip
+    mock_ec2_instance.state_reason = {}
+    mock_ec2_instance.state = {"Name": "Fake Name"}
+    mock_ec2_client.create_instances = Mock(return_value=[mock_ec2_instance])
+    provider_config = {"region": "us-west-2", "cache_stopped_nodes": False}
+    with patch.multiple(
+        "ray.autoscaler._private.aws.node_provider",
+        make_ec2_client=Mock(return_value=mock_ec2_client),
+    ):
+        node_provider = AnyscaleAWSNodeProvider(provider_config, "fake_cluster_name")
+        created_node = node_provider.create_node({"SubnetIds": "123"}, tags={}, count=1)
+
+        assert created_node[mock_instance_id]["PublicIpAddress"] == mock_instance_ip
