@@ -2,12 +2,12 @@ from datetime import datetime, timezone
 from typing import Any
 from unittest.mock import Mock, patch
 
-
 import pytest
 
-from anyscale.client.openapi_client import (  # type: ignore
+from anyscale.client.openapi_client import (
     Cloud,
     ExecuteCommandResponse,
+    Organization,
     Project,
     Session,
     SessionCommand,
@@ -15,6 +15,7 @@ from anyscale.client.openapi_client import (  # type: ignore
     SessionListResponse,
     SessionStartingUpData,
     SessionStateData,
+    UserInfo,
 )
 
 
@@ -24,6 +25,12 @@ def base_mock_api_client() -> Mock:
     return mock_api_client
 
 
+@pytest.fixture()
+def base_mock_anyscale_api_client() -> Mock:
+    mock_anyscale_api_client = Mock()
+    return mock_anyscale_api_client
+
+
 @pytest.fixture()
 def mock_api_client_with_session(
     base_mock_api_client: Mock, session_test_data: Session
@@ -136,6 +143,29 @@ def command_id_test_data() -> ExecuteCommandResponse:
     )
 
 
+@pytest.fixture(scope="module")
+def userinfo_test_data() -> UserInfo:
+    return UserInfo(
+        id="mock_user_id",
+        email="mock_email",
+        name="mock_name",
+        username="mock_user_name",
+        verified=True,
+        organization_permission_level="owner",
+        organization_ids=["mock_org_id_1"],
+        organizations=[
+            Organization(
+                id="mock_org_id_1",
+                name="mock_org_1",
+                public_identifier="mock_org_1",
+                default_cloud_id="mock_default_cloud_id",
+            )
+        ],
+        ld_hash="mock_ld_hash",
+        ld_hash_fields=["email", "name", "username", "organization_ids"],
+    )
+
+
 @pytest.fixture(scope="session", autouse=True)
 def default_session_fixture(
     request: "_pytest.fixtures.SubRequest",  # type: ignore # noqa: F821
