@@ -4,13 +4,13 @@ from unittest.mock import Mock, patch
 from click import ClickException
 import pytest
 
-from anyscale.client.openapi_client.models import (  # type: ignore
+from anyscale.client.openapi_client.models import (
     AnyscaleAWSAccount,
     AnyscaleawsaccountResponse,
     Cloud,
     CloudResponse,
 )
-from anyscale.client.openapi_client.models.cloud_config import CloudConfig  # type: ignore
+from anyscale.client.openapi_client.models.cloud_config import CloudConfig
 from anyscale.controllers.cloud_controller import CloudController
 
 
@@ -202,3 +202,24 @@ def test_update_cloud_config_by_id(
         cloud_id=cloud_test_data.id,
         cloud_config=CloudConfig(max_stopped_instances=100),
     )
+
+
+@pytest.mark.parametrize("cloud_id", [None, "cloud_id_1"])
+@pytest.mark.parametrize("cloud_name", [None, "cloud_name_1"])
+def test_set_default_cloud(
+    mock_api_client: Mock, cloud_id: Optional[str], cloud_name: Optional[str]
+) -> None:
+    cloud_controller = CloudController(api_client=mock_api_client)
+    if not (cloud_id or cloud_name) or (cloud_id and cloud_name):
+        # Error if neither or both of cloud_id and cloud_name provided
+        with pytest.raises(ClickException):
+            cloud_controller.set_default_cloud(
+                cloud_id=cloud_id, cloud_name=cloud_name,
+            )
+    else:
+        cloud_controller.set_default_cloud(
+            cloud_id=cloud_id, cloud_name=cloud_name,
+        )
+        mock_api_client.update_default_cloud_api_v2_organizations_update_default_cloud_post.assert_called_once_with(
+            cloud_id="cloud_id_1"
+        )
