@@ -4,15 +4,19 @@ from unittest.mock import ANY, Mock, patch
 
 import pytest
 
-from anyscale.client.openapi_client.models.cloud import Cloud  # type: ignore
-from anyscale.client.openapi_client.models.cloud_list_response import CloudListResponse  # type: ignore
-from anyscale.client.openapi_client.models.cloud_response import CloudResponse  # type: ignore
-from anyscale.client.openapi_client.models.project import Project  # type: ignore
-from anyscale.client.openapi_client.models.project_list_response import ProjectListResponse  # type: ignore
-from anyscale.client.openapi_client.models.project_response import ProjectResponse  # type: ignore
-from anyscale.client.openapi_client.models.session import Session  # type: ignore
-from anyscale.client.openapi_client.models.session_command import SessionCommand  # type: ignore
-from anyscale.client.openapi_client.models.sessioncommand_list_response import SessioncommandListResponse  # type: ignore
+from anyscale.client.openapi_client.models.cloud import Cloud
+from anyscale.client.openapi_client.models.cloud_list_response import CloudListResponse
+from anyscale.client.openapi_client.models.cloud_response import CloudResponse
+from anyscale.client.openapi_client.models.project import Project
+from anyscale.client.openapi_client.models.project_list_response import (
+    ProjectListResponse,
+)
+from anyscale.client.openapi_client.models.project_response import ProjectResponse
+from anyscale.client.openapi_client.models.session import Session
+from anyscale.client.openapi_client.models.session_command import SessionCommand
+from anyscale.client.openapi_client.models.sessioncommand_list_response import (
+    SessioncommandListResponse,
+)
 from anyscale.controllers.list_controller import ListController
 from anyscale.util import humanize_timestamp
 
@@ -186,6 +190,7 @@ def test_list_sessions_json(
                     "startup_error": {},
                     "stop_error": {},
                     "created_at": time.mktime(session_test_data.created_at.timetuple()),
+                    "connect_url": None,
                     "jupyter_notebook_url": None,
                     "ray_dashboard_url": None,
                     "grafana_url": None,
@@ -258,7 +263,7 @@ def test_list_ips_table(session_test_data: Session, mock_api_client: Mock) -> No
     mock_api_client.list_sessions_api_v2_sessions_get.assert_called_once_with(
         project_id=session_test_data.project_id,
         name_match=None,
-        active_only=True,
+        state_filter=["AwaitingFileMounts", "Running"],
         _request_timeout=ANY,
     )
     mock_get_head_and_worker_ip.assert_called_once_with(
@@ -317,7 +322,7 @@ def test_list_ips_json(
     mock_api_client.list_sessions_api_v2_sessions_get.assert_called_with(
         project_id=session_test_data.project_id,
         name_match=session_test_data.name,
-        active_only=True,
+        state_filter=["AwaitingFileMounts", "Running"],
         _request_timeout=ANY,
     )
     mock_api_client.get_session_commands_history_api_v2_session_commands_get.assert_called_once_with(
