@@ -9,9 +9,13 @@ import click
 import pytest
 import yaml
 
-from anyscale.client.openapi_client import (  # type: ignore
+from anyscale.client.openapi_client import (
+    AppConfig,
+    Build,
     Cloud,
     ClusterConfig,
+    ComputeTemplateConfig,
+    CreateComputeTemplate,
     CreateSessionFromSnapshotOptions,
     Project,
     ProjectDefaultSessionName,
@@ -28,6 +32,11 @@ from anyscale.client.openapi_client import (  # type: ignore
 )
 from anyscale.controllers.session_controller import SessionController
 from anyscale.project import CLUSTER_YAML_TEMPLATE
+from anyscale.sdk.anyscale_client import (
+    CreateSession,
+    StartSessionOptions,
+    UpdateSession,
+)
 
 
 COMPUTE_CONFIG_TEMPLATE = json.dumps(
@@ -73,8 +82,14 @@ def mock_api_client(mock_api_client_with_session: Mock) -> Mock:
     return mock_api_client
 
 
-def test_stop_single_session(session_test_data: Session, mock_api_client: Mock) -> None:
-    session_controller = SessionController(api_client=mock_api_client)
+def test_stop_single_session(
+    session_test_data: Session,
+    mock_api_client: Mock,
+    base_mock_anyscale_api_client: Mock,
+) -> None:
+    session_controller = SessionController(
+        api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
+    )
 
     mock_project_definition = Mock()
     mock_project_definition.root = "/some/directory"
@@ -142,9 +157,13 @@ def mock_api_client_multiple_sessions(base_mock_api_client: Mock) -> Mock:
     return base_mock_api_client
 
 
-def test_stop_multiple_sessions(mock_api_client_multiple_sessions: Mock) -> None:
+def test_stop_multiple_sessions(
+    mock_api_client_multiple_sessions: Mock, base_mock_anyscale_api_client: Mock
+) -> None:
     mock_api_client = mock_api_client_multiple_sessions
-    session_controller = SessionController(api_client=mock_api_client)
+    session_controller = SessionController(
+        api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
+    )
 
     mock_project_definition = Mock()
     mock_project_definition.root = "/some/directory"
@@ -214,18 +233,24 @@ def mock_up_tuple(
         _update_file_mounts=MagicMock(
             side_effect=lambda cluster_config, project_root_dir, api_client: cluster_config
         ),
+        get_working_dir=Mock(return_value="mock_working_dir"),
     ):
         yield base_mock_api_client, project_test_data, cloud_test_data, mock_wait_for_session_start
 
 
-def test_anyscale_up_success(mock_up_tuple: Tuple[Mock, Project, Cloud, Mock]) -> None:
+def test_anyscale_up_success(
+    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
+    base_mock_anyscale_api_client: Mock,
+) -> None:
     (
         mock_api_client,
         project_test_data,
         cloud_test_data,
         mock_wait_for_start,
     ) = mock_up_tuple
-    session_controller = SessionController(api_client=mock_api_client)
+    session_controller = SessionController(
+        api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
+    )
     session_controller.push = Mock()  # type: ignore
     mock_api_client.get_project_default_session_name_api_v2_projects_project_id_default_session_name_get.return_value = ProjectdefaultsessionnameResponse(
         result=ProjectDefaultSessionName(name="session-11")
@@ -286,14 +311,19 @@ def test_anyscale_up_success(mock_up_tuple: Tuple[Mock, Project, Cloud, Mock]) -
         )
 
 
-def test_anyscale_up_failure(mock_up_tuple: Tuple[Mock, Project, Cloud, Mock]) -> None:
+def test_anyscale_up_failure(
+    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
+    base_mock_anyscale_api_client: Mock,
+) -> None:
     (
         mock_api_client,
         project_test_data,
         cloud_test_data,
         mock_wait_for_start,
     ) = mock_up_tuple
-    session_controller = SessionController(api_client=mock_api_client)
+    session_controller = SessionController(
+        api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
+    )
     session_controller.push = Mock()  # type: ignore
     sesion_id = "session-10"
     mock_api_client.get_project_default_session_name_api_v2_projects_project_id_default_session_name_get.return_value = ProjectdefaultsessionnameResponse(
@@ -333,7 +363,8 @@ def test_anyscale_up_failure(mock_up_tuple: Tuple[Mock, Project, Cloud, Mock]) -
 
 
 def test_anyscale_up_no_config_provided(
-    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock]
+    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
+    base_mock_anyscale_api_client: Mock,
 ) -> None:
     (
         mock_api_client,
@@ -341,7 +372,9 @@ def test_anyscale_up_no_config_provided(
         cloud_test_data,
         mock_wait_for_start,
     ) = mock_up_tuple
-    session_controller = SessionController(api_client=mock_api_client)
+    session_controller = SessionController(
+        api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
+    )
     session_controller.push = Mock()  # type: ignore
     mock_api_client.get_project_default_session_name_api_v2_projects_project_id_default_session_name_get.return_value = ProjectdefaultsessionnameResponse(
         result=ProjectDefaultSessionName(name="session-11")
@@ -406,7 +439,8 @@ def test_anyscale_up_no_config_provided(
 
 
 def test_anyscale_app_template(
-    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock]
+    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
+    base_mock_anyscale_api_client: Mock,
 ) -> None:
     (
         mock_api_client,
@@ -414,7 +448,9 @@ def test_anyscale_app_template(
         cloud_test_data,
         mock_wait_for_start,
     ) = mock_up_tuple
-    session_controller = SessionController(api_client=mock_api_client)
+    session_controller = SessionController(
+        api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
+    )
     session_controller.push = Mock()  # type: ignore
     mock_api_client.get_project_default_session_name_api_v2_projects_project_id_default_session_name_get.return_value = ProjectdefaultsessionnameResponse(
         result=ProjectDefaultSessionName(name="session-11")
@@ -476,10 +512,300 @@ def test_anyscale_app_template(
         )
 
 
-def test_ssh_session(
-    session_test_data: Session, mock_api_client_multiple_sessions: Mock
+def test_get_or_generate_session_name(
+    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
+    base_mock_anyscale_api_client: Mock,
 ) -> None:
-    session_controller = SessionController(api_client=mock_api_client_multiple_sessions)
+    (mock_api_client, project_test_data, _, _) = mock_up_tuple
+    mock_api_client.get_project_default_session_name_api_v2_projects_project_id_default_session_name_get.return_value = ProjectdefaultsessionnameResponse(
+        result=ProjectDefaultSessionName(name="session-11")
+    )
+
+    session_controller = SessionController(
+        api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
+    )
+    session_controller._get_or_generate_session_name(None, project_test_data.id)
+    mock_api_client.get_project_default_session_name_api_v2_projects_project_id_default_session_name_get.assert_called_once_with(
+        project_id=project_test_data.id
+    )
+
+
+def test_register_compute_config(
+    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
+    base_mock_anyscale_api_client: Mock,
+) -> None:
+    (mock_api_client, project_test_data, _, _) = mock_up_tuple
+    mock_api_client.create_compute_template_api_v2_compute_templates_post = Mock(
+        return_value=Mock(result=Mock(id="mock_compute_template_id"))
+    )
+    session_controller = SessionController(
+        api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
+    )
+    with tempfile.NamedTemporaryFile(mode="w") as temp_file:
+        temp_file.write(COMPUTE_CONFIG_TEMPLATE)
+        temp_file.flush()
+        session_controller._register_compute_config(
+            temp_file.name, project_test_data.id
+        )
+
+    config_object = ComputeTemplateConfig(**yaml.safe_load(COMPUTE_CONFIG_TEMPLATE))
+    create_compute_template = CreateComputeTemplate(
+        name=ANY, project_id=project_test_data.id, config=config_object,
+    )
+    mock_api_client.create_compute_template_api_v2_compute_templates_post.assert_called_once_with(
+        create_compute_template=create_compute_template
+    )
+
+
+@pytest.mark.parametrize("update_session", [False, True])
+def test_create_or_update_session_data(
+    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
+    base_mock_anyscale_api_client: Mock,
+    update_session: bool,
+) -> None:
+    (mock_api_client, project_test_data, _, _) = mock_up_tuple
+    if update_session:
+        mock_api_client.list_sessions_api_v2_sessions_get.return_value = SessionListResponse(
+            results=[Mock(id="session-11-id")]  # Session already exists.
+        )
+    else:
+        mock_api_client.list_sessions_api_v2_sessions_get.return_value = SessionListResponse(
+            results=[]  # No session with this name yet, brand new session.
+        )
+    session_controller = SessionController(
+        api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
+    )
+    session_controller._create_or_update_session_data(
+        session_name="session-11",
+        project_id=project_test_data.id,
+        build_id="mock_build_id",
+        compute_template_id="mock_compute_template_id",
+        idle_timeout=-1,
+    )
+
+    if update_session:
+        base_mock_anyscale_api_client.update_session.assert_called_once_with(
+            "session-11-id", UpdateSession(idle_timeout=-1,),
+        )
+    else:
+        create_session_data = CreateSession(
+            name="session-11",
+            project_id=project_test_data.id,
+            cloud_id=None,
+            cluster_config=None,
+            build_id="mock_build_id",
+            compute_template_id="mock_compute_template_id",
+            idle_timeout=-1,
+            uses_app_config=True,
+        )
+        base_mock_anyscale_api_client.create_session.assert_called_once_with(
+            create_session_data
+        )
+
+
+def test_list_app_configs(
+    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
+    base_mock_anyscale_api_client: Mock,
+) -> None:
+    (mock_api_client, project_test_data, _, _) = mock_up_tuple
+    base_mock_anyscale_api_client.list_app_configs = Mock(
+        return_value=Mock(results=[], metadata=Mock(next_paging_token=None))
+    )
+    session_controller = SessionController(
+        api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
+    )
+    session_controller._list_app_configs(project_test_data.id)
+    base_mock_anyscale_api_client.list_app_configs.assert_called_once_with(
+        project_test_data.id, count=50, paging_token=None
+    )
+
+
+def test_list_builds(
+    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
+    base_mock_anyscale_api_client: Mock,
+) -> None:
+    (mock_api_client, _, _, _) = mock_up_tuple
+    base_mock_anyscale_api_client.list_builds = Mock(
+        return_value=Mock(results=[], metadata=Mock(next_paging_token=None))
+    )
+    session_controller = SessionController(
+        api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
+    )
+    session_controller._list_builds("mock_app_config_id")
+    base_mock_anyscale_api_client.list_builds.assert_called_once_with(
+        "mock_app_config_id", count=50, paging_token=None
+    )
+
+
+def test_get_app_config_id_from_name(
+    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
+    base_mock_anyscale_api_client: Mock,
+) -> None:
+    (mock_api_client, project_test_data, _, _) = mock_up_tuple
+    session_controller = SessionController(
+        api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
+    )
+    session_controller._list_app_configs = Mock(  # type: ignore
+        return_value=[
+            AppConfig(
+                name="mock_app_config_name",
+                id="mock_app_config_id",
+                project_id=project_test_data.id,
+                creator_id=ANY,
+                created_at=ANY,
+                last_modified_at=ANY,
+            )
+        ]
+    )
+
+    app_config_id = session_controller._get_app_config_id_from_name(
+        "mock_app_config_name", project_test_data.id
+    )
+    assert app_config_id == "mock_app_config_id"
+    session_controller._list_app_configs.assert_called_once_with(project_test_data.id)
+
+
+@pytest.mark.parametrize("build_identifier", ["my_app_config:1", "my_app_config"])
+def test_get_build_id_from_build_identifier(
+    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
+    base_mock_anyscale_api_client: Mock,
+    build_identifier: str,
+) -> None:
+    (mock_api_client, project_test_data, _, _) = mock_up_tuple
+    session_controller = SessionController(
+        api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
+    )
+    session_controller._get_app_config_id_from_name = Mock(  # type: ignore
+        return_value="mock_app_config_id"
+    )
+    session_controller._list_builds = Mock(  # type: ignore
+        return_value=[
+            Build(
+                revision=1,
+                id="mock_build_id_1",
+                application_template_id="mock_app_config_id",
+                config_json=ANY,
+                creator_id=ANY,
+                status=ANY,
+                created_at=ANY,
+                last_modified_at=ANY,
+            ),
+            Build(
+                revision=2,
+                id="mock_build_id_2",
+                application_template_id="mock_app_config_id",
+                config_json=ANY,
+                creator_id=ANY,
+                status=ANY,
+                created_at=ANY,
+                last_modified_at=ANY,
+            ),
+        ]
+    )
+    build_id = session_controller._get_build_id_from_build_identifier(
+        build_identifier, project_test_data.id
+    )
+    if build_identifier == "my_app_config":
+        assert build_id == "mock_build_id_2"
+    elif build_identifier == "my_app_config:1":
+        assert build_id == "mock_build_id_1"
+
+    session_controller._get_app_config_id_from_name.assert_called_once_with(
+        "my_app_config", project_test_data.id
+    )
+    session_controller._list_builds.assert_called_once_with("mock_app_config_id")
+
+
+@pytest.mark.parametrize("sync_files", [False, True])
+@pytest.mark.parametrize("use_build_id", [False, True])
+def test_anyscale_start(
+    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
+    base_mock_anyscale_api_client: Mock,
+    sync_files: bool,
+    use_build_id: bool,
+) -> None:
+    (mock_api_client, project_test_data, _, mock_wait_for_start,) = mock_up_tuple
+    session_controller = SessionController(
+        api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
+    )
+    session_controller.push = Mock()  # type: ignore
+    session_controller._get_or_generate_session_name = Mock(return_value="session-11")  # type: ignore
+    session_controller._register_compute_config = Mock(  # type: ignore
+        return_value="mock_compute_template_id"
+    )
+    session_controller._create_or_update_session_data = Mock(  # type: ignore
+        return_value=Mock(id="session-11-id")
+    )
+    session_controller._get_build_id_from_build_identifier = Mock(  # type: ignore
+        return_value="mock_build_id"
+    )
+
+    if sync_files:
+        # Check --sync-files is deprecated
+        with pytest.raises(click.ClickException):
+            session_controller.start(
+                session_name=None,
+                build_id=None,
+                build_identifier="mock_build_identifier",
+                compute_config="mock_compute_config_file",
+                idle_timeout=-1,
+                sync_files=sync_files,
+            )
+    elif use_build_id:
+        session_controller.start(
+            session_name=None,
+            build_id="mock_build_id",
+            build_identifier=None,
+            compute_config="mock_compute_config_file",
+            idle_timeout=-1,
+            sync_files=sync_files,
+        )
+    else:
+        session_controller.start(
+            session_name=None,
+            build_id=None,
+            build_identifier="mock_build_identifier",
+            compute_config="mock_compute_config_file",
+            idle_timeout=-1,
+            sync_files=sync_files,
+        )
+
+    if not sync_files:
+        session_controller._get_or_generate_session_name.assert_called_once_with(
+            None, project_test_data.id
+        )
+        session_controller._register_compute_config.assert_called_once_with(
+            "mock_compute_config_file", project_test_data.id
+        )
+        session_controller._create_or_update_session_data.assert_called_once_with(
+            "session-11",
+            project_test_data.id,
+            "mock_build_id",
+            "mock_compute_template_id",
+            -1,
+        )
+        base_mock_anyscale_api_client.start_session.assert_called_once_with(
+            "session-11-id",
+            StartSessionOptions(
+                build_id="mock_build_id", compute_template_id="mock_compute_template_id"
+            ),
+        )
+
+        if not use_build_id:
+            session_controller._get_build_id_from_build_identifier.assert_called_once_with(
+                "mock_build_identifier", project_test_data.id
+            )
+
+
+def test_ssh_session(
+    session_test_data: Session,
+    mock_api_client_multiple_sessions: Mock,
+    base_mock_anyscale_api_client: Mock,
+) -> None:
+    session_controller = SessionController(
+        api_client=mock_api_client_multiple_sessions,
+        anyscale_api_client=base_mock_anyscale_api_client,
+    )
 
     mock_project_definition = Mock()
     mock_project_definition.root = "/some/directory"
@@ -514,7 +840,9 @@ def test_ssh_session(
 
 
 def test_autopush(
-    session_test_data: Session, mock_api_client_with_session: Mock
+    session_test_data: Session,
+    mock_api_client_with_session: Mock,
+    base_mock_anyscale_api_client: Mock,
 ) -> None:
     mock_api_client_with_session.get_session_head_ip_api_v2_sessions_session_id_head_ip_get.return_value.result.head_ip = (
         "127.0.0.1"
@@ -538,7 +866,10 @@ def test_autopush(
     mock_perform_sync = Mock()
     mock_perform_sync.return_value.returncode = 0
 
-    session_controller = SessionController(api_client=mock_api_client_with_session)
+    session_controller = SessionController(
+        api_client=mock_api_client_with_session,
+        anyscale_api_client=base_mock_anyscale_api_client,
+    )
 
     with patch.multiple(
         "anyscale.controllers.session_controller",
@@ -603,7 +934,9 @@ def test_autopush(
 
 
 def test_autosync_docker(
-    session_test_data: Session, mock_api_client_with_session: Mock
+    session_test_data: Session,
+    mock_api_client_with_session: Mock,
+    base_mock_anyscale_api_client: Mock,
 ) -> None:
     mock_api_client_with_session.get_session_head_ip_api_v2_sessions_session_id_head_ip_get.return_value.result.head_ip = (
         "127.0.0.1"
@@ -631,7 +964,10 @@ def test_autosync_docker(
     mock_perform_sync = Mock()
     mock_perform_sync.return_value.returncode = 0
 
-    session_controller = SessionController(api_client=mock_api_client_with_session)
+    session_controller = SessionController(
+        api_client=mock_api_client_with_session,
+        anyscale_api_client=base_mock_anyscale_api_client,
+    )
 
     remote_location = "/fake/host/mount"
     mock_subprocess_run = Mock()
@@ -702,7 +1038,9 @@ def test_autosync_docker(
 
 
 def test_anyscale_push_session(
-    session_test_data: Session, mock_api_client_with_session: Mock
+    session_test_data: Session,
+    mock_api_client_with_session: Mock,
+    base_mock_anyscale_api_client: Mock,
 ) -> None:
     mock_project_definition = Mock()
     mock_project_definition.root = "/some/directory"
@@ -723,7 +1061,10 @@ def test_anyscale_push_session(
     mock_rsync = Mock()
     mock_up = Mock()
 
-    session_controller = SessionController(api_client=mock_api_client_with_session)
+    session_controller = SessionController(
+        api_client=mock_api_client_with_session,
+        anyscale_api_client=base_mock_anyscale_api_client,
+    )
 
     with patch.multiple("subprocess", run=mock_subprocess_run), patch.multiple(
         "anyscale.controllers.session_controller",
@@ -738,7 +1079,7 @@ def test_anyscale_push_session(
         source = "TestSource"
         target = "TestTarget"
         config = "TestConfig"
-        all_nodes = True
+        all_nodes = False
         session_controller.push(session_name, source, target, config, all_nodes)
 
         # Don't check the config_file argument because it's a random path of
@@ -769,7 +1110,10 @@ def test_anyscale_push_session(
 
 @pytest.mark.parametrize("config", [None, "tmp.yaml"])
 def test_pull(
-    session_test_data: Session, mock_api_client_with_session: Mock, config: str
+    session_test_data: Session,
+    mock_api_client_with_session: Mock,
+    base_mock_anyscale_api_client: Mock,
+    config: str,
 ) -> None:
     mock_project_definition = Mock()
     mock_project_definition.root = "/some/directory"
@@ -784,7 +1128,10 @@ def test_pull(
         "temp"
     )
 
-    session_controller = SessionController(api_client=mock_api_client_with_session)
+    session_controller = SessionController(
+        api_client=mock_api_client_with_session,
+        anyscale_api_client=base_mock_anyscale_api_client,
+    )
 
     with patch.multiple(
         "anyscale.controllers.session_controller",
@@ -821,6 +1168,7 @@ def test_pull(
 def test_fork_session(
     session_test_data: Session,
     mock_api_client_with_session: Mock,
+    base_mock_anyscale_api_client: Mock,
     project_name: Optional[str],
 ) -> None:
 
@@ -829,7 +1177,10 @@ def test_fork_session(
     ) as mock_resolve_session, patch.object(
         SessionController, "_fork_session_internal", return_value=session_test_data
     ) as mock_fork_session_internal:
-        session_controller = SessionController(mock_api_client_with_session)
+        session_controller = SessionController(
+            api_client=mock_api_client_with_session,
+            anyscale_api_client=base_mock_anyscale_api_client,
+        )
         output_str = session_controller.fork_session(
             "session_name", "new_session_name", project_name
         )
@@ -848,6 +1199,7 @@ def test_resolve_session(
     project_test_data: Project,
     session_test_data: Session,
     mock_api_client_with_session: Mock,
+    base_mock_anyscale_api_client: Mock,
     project_name: Optional[str],
 ) -> None:
     mock_project_definition = Mock()
@@ -868,7 +1220,10 @@ def test_resolve_session(
         load_project_or_throw=mock_load_project_or_throw,
         get_project_id=mock_get_project_id,
     ):
-        session_controller = SessionController(mock_api_client_with_session)
+        session_controller = SessionController(
+            api_client=mock_api_client_with_session,
+            anyscale_api_client=base_mock_anyscale_api_client,
+        )
         session = session_controller._resolve_session("session_name", project_name)
 
     assert session == session_test_data
@@ -888,7 +1243,9 @@ def test_resolve_session(
 
 
 def test_fork_session_internal(
-    session_test_data: Session, mock_api_client_with_session: Mock
+    session_test_data: Session,
+    mock_api_client_with_session: Mock,
+    base_mock_anyscale_api_client: Mock,
 ) -> None:
     mock_api_client_with_session.fork_session_api_v2_sessions_session_id_fork_post.return_value = (
         None
@@ -897,7 +1254,10 @@ def test_fork_session_internal(
         results=[session_test_data]
     )
 
-    session_controller = SessionController(mock_api_client_with_session)
+    session_controller = SessionController(
+        api_client=mock_api_client_with_session,
+        anyscale_api_client=base_mock_anyscale_api_client,
+    )
     cloned_session = session_controller._fork_session_internal(
         session_test_data, "new_session_name"
     )
