@@ -4,10 +4,12 @@ from unittest.mock import ANY, Mock, mock_open, patch
 
 import pytest
 
-from anyscale.client.openapi_client.models.project import Project  # type: ignore
-from anyscale.client.openapi_client.models.project_response import ProjectResponse  # type: ignore
-from anyscale.client.openapi_client.models.session import Session  # type: ignore
-from anyscale.client.openapi_client.models.session_list_response import SessionListResponse  # type: ignore
+from anyscale.client.openapi_client.models.project import Project
+from anyscale.client.openapi_client.models.project_response import ProjectResponse
+from anyscale.client.openapi_client.models.session import Session
+from anyscale.client.openapi_client.models.session_list_response import (
+    SessionListResponse,
+)
 from anyscale.project import (
     clone_cluster_config,
     create_new_proj_def,
@@ -30,6 +32,18 @@ def test_get_project_sessions(session_test_data: Session) -> None:
 
     assert sessions == [session_test_data]
     mock_api_client.list_sessions_api_v2_sessions_get.assert_called_once_with(
+        project_id=session_test_data.project_id,
+        name_match=None,
+        state_filter=["AwaitingFileMounts", "Running"],
+        _request_timeout=ANY,
+    )
+
+    sessions = get_project_sessions(
+        session_test_data.project_id, None, mock_api_client, all_active_states=True
+    )
+
+    assert sessions == [session_test_data]
+    mock_api_client.list_sessions_api_v2_sessions_get.assert_called_with(
         project_id=session_test_data.project_id,
         name_match=None,
         active_only=True,
@@ -49,7 +63,7 @@ def test_get_project_session(session_test_data: Session) -> None:
     mock_api_client.list_sessions_api_v2_sessions_get.assert_called_once_with(
         project_id=session_test_data.project_id,
         name_match=None,
-        active_only=True,
+        state_filter=["AwaitingFileMounts", "Running"],
         _request_timeout=ANY,
     )
 
